@@ -7,9 +7,6 @@ class WinkAirConditioner(WinkDevice):
     Represents a Wink air conditioner.
     """
 
-    def __init__(self, device_state_as_json, api_interface):
-        super(WinkAirConditioner, self).__init__(device_state_as_json, api_interface)
-
     def state(self):
         return self.current_mode()
 
